# pyDIOPT

This is the unofficial DIOPT python wrapper for the [DIOPT](https://www.flyrnai.org/cgi-bin/DRSC_orthologs.pl) ortholog finder.

## Acknowledgement

-   This repo is boilerplated from [py-package-template](https://github.com/AlexIoannides/py-package-template)
